body {
    background-color: #efefef;
    font-size: 14px;
    padding: 0;
    margin: 0;
}

p {
    font-size: 14px;
}

.wrapper {
    width: 1024px;
    margin: 30px auto;
}

.logohint {
    background: #ebf5ea;
    margin: 0 -20px -20px -20px;
    padding: 20px;
    font-size: 14px;
    border-top: 1px solid #d2e6da;
    font-size: 18px;
}

.nav {
    font-size: 14px;
    display: block;
    float: right;
    text-decoration: none;
    color: #aaa;
}

.nav a {
    color: #000;
    text-decoration: none;
    margin-left: 10px;
}


.top_block, .block {
    border: solid 1px #dbdbdb;
    margin-bottom: 10px;
    background-color: #fff;
}

.block {
    border-left: 5px solid #0cbd54;
    padding: 20px;
}

.top_block {
    padding: 8px 16px;
}

.name {
    text-decoration: none;
    font-size: 18px;
    color: #616354;
    display: block;
    float: left;
}

.logo:hover {
    color: #322e38;
}

td {
    border-left-width: 0;
    border-right-width: 0;
    border-spacing: 0 0;
    border-top-width: 0;
    font-size: 13px;
    padding: 10px 50px 10px 0;
    border-bottom: solid 1px #eee;
}

table {
    border-spacing: 0;
    border: none;
    width: 100%;
}

table em {
    color: #838383;
}

.table_header
{
    color: #929292;
}

code {
    background-color: #fcfcfc;
    padding: 0 4px;
}

.code
{
    background-color: #fcfcfc;
    padding: 20px;
    border: solid 1px #e9e9e9;
}

a {
    color: #305d98;
    text-decoration: none;
}

.logo {
    color: #212020e6;
    font-size: 1.6em;
    margin: 10px;
}
.logo sup {
    color: #0cbd54;
    font-size: 0.4em;
    margin-left: 6px;
    margin-top: 0;
}